@@ -24,7 +24,7 @@
 */
 var NAVTREE =
 [
-  [ "FLTK", "index.html", [
+  [ "FLTK 1.3.7", "index.html", [
     [ "FLTK Programming Manual", "index.html", "index" ],
     [ "Todo List", "todo.html", null ],
     [ "Deprecated List", "deprecated.html", null ],
@@ -62,25 +62,24 @@ var NAVTREEINDEX =
 [
 "Enumerations_8H.html",
 "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a9edbfd236c9ea348dcaae935a76bd885",
-"Fl__Paged__Device_8H.html#ad85fd91db75c56dcf6696635c1db0aff",
-"classFl__Browser__.html#a2302bec54f4ea593146be5490a7fe93b",
-"classFl__FLTK__File__Chooser.html#a94c93232b73eef3c6ee275d8fdbf7802",
-"classFl__Graphics__Driver.html#a208595f1c4e4bd0c32ee5a56194b405c",
-"classFl__Image.html#a7cf92084aede6baa2bdb00caa8f5a010",
-"classFl__Overlay__Window.html#a6bdc30c7d7941e7542e230904bc9de2d",
-"classFl__Preferences.html#a6602c3104b2c5259160cb7e0fe5dd335",
-"classFl__Spinner.html#a4e2ea3fbdf8d7653d3dc1440d58434cf",
-"classFl__Text__Buffer.html#a3194e63f030767326476d4e719d69a32",
-"classFl__Text__Display.html#ae6ab1a7e2bdee0730730710c3e5e310f",
-"classFl__Tree__Item.html#a1d92235d11914f88f3b232e509bd2514",
-"classFl__Value__Output.html#a9c9b1bdb0f3862f7709aa56ae0c4182f",
-"classFl__Xlib__Graphics__Driver.html#a2483bf6da5735a7141ada57b7eca2ae4",
-"fl__boxtype_8cxx.html#a3d6c905e0e037c1f962f019679978d4c",
-"glut_8H.html#adf764cbdea00d65edcd07bb9953ad2b7a563dde7b29f2a6d90dd96bb4a74752c5",
-"group__fl__drawings.html#ga06fc87d81c62e9abb8790b6e5713c55ba9062ebd4dae14dde6a892ca36b429d6c",
-"group__fl__drawings.html#gacf46b232b6439424cc7f53656c5c2226",
-"group__group__comdlg.html#ga5cb8a823f404d44994862d198b3a82b1",
-"structFl__Menu__Item.html#a6983103fb99e1fee59dd705bb2d23147"
+"Fl__Printer_8H.html",
+"classFl__Browser__.html#a4d59d5c7d78393a7a5d5bfaa01694580",
+"classFl__FLTK__File__Chooser.html#af31ba0b3afe6257b7ed246bf321fb8cd",
+"classFl__Graphics__Driver.html#a534f2ce7e973705cb934f6e6304d3636",
+"classFl__Input__.html#a23997fbc020994386594fbc6bb7a6548",
+"classFl__Paged__Device.html#ab91583935e45f9f85b7abf79c2bcda81",
+"classFl__Preferences_1_1Node.html#a37b1824545019d748cf00672861cc1dc",
+"classFl__Sys__Menu__Bar.html#ade5c2840df6c3b4b564c09018ff6dc0d",
+"classFl__Text__Buffer.html#aa429406d9ae922379a89519cda8b82b5",
+"classFl__Tiled__Image.html#a9d22f2345513330c2d21d11bb75f2087",
+"classFl__Tree__Item.html#a9e72a148688f46df8e87793510043032",
+"classFl__Widget.html#a7f05e24d343941328fa38958feab4168",
+"editor.html#editor_replace_dialog",
+"forms.html#forms_using",
+"group__fl__attributes.html#ga5c8dfa051e445cff49726b256b9f1ca0",
+"group__fl__drawings.html#gaf98789ec460134ffc81f2af2d2db6857",
+"group__group__comdlg.html#gad14c8bab4536ccb1ee8258bcd0f9ff1e",
+"structFl__Menu__Item.html#a996db6347b53fc0ea8ab6ae763a44a2c"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
