@@ -1,50 +1,5 @@
 var NAVTREEINDEX9 =
 {
-"classFl__Spinner.html#a4e2ea3fbdf8d7653d3dc1440d58434cf":[4,0,122,5],
-"classFl__Spinner.html#a59525ba1c1b9a68324c118ca38dc590b":[4,0,122,23],
-"classFl__Spinner.html#a59aba03e82860850dd3d0744535c32c6":[4,0,122,28],
-"classFl__Spinner.html#a646aa13b7a6219a855b27eb881ab9872":[4,0,122,9],
-"classFl__Spinner.html#a6479f39047e9c58f864bf61313288a60":[4,0,122,7],
-"classFl__Spinner.html#a6914361661aedac1e4529379625877f1":[4,0,122,1],
-"classFl__Spinner.html#a6d2908d8e037b6e3d73d2e09dedcbe5b":[4,0,122,10],
-"classFl__Spinner.html#a6fa7f6a07c3cb7245dc2a9eb6350d008":[4,0,122,11],
-"classFl__Spinner.html#a7b9f95b2a6a5c3be1995a89b518a6eb2":[4,0,122,24],
-"classFl__Spinner.html#a84a1e43149b538ce69a2309aabac0814":[4,0,122,0],
-"classFl__Spinner.html#a93f1c99df8cd04f7d43f382b9e20f786":[4,0,122,13],
-"classFl__Spinner.html#a9457ad1e5c117f7dd56e70f28ff5fe19":[4,0,122,21],
-"classFl__Spinner.html#a97bff05565b3cc8b4082d39a211290dd":[4,0,122,14],
-"classFl__Spinner.html#a9c7d15e418fd2360879705287feed852":[4,0,122,22],
-"classFl__Spinner.html#aa1e6cace6f88b672a7d8ba219bf0c248":[4,0,122,4],
-"classFl__Spinner.html#ab7b053d8d9c92f411c86fe2a15c2631d":[4,0,122,12],
-"classFl__Spinner.html#abee4b9eab726c7b88a946751118ae7d2":[4,0,122,8],
-"classFl__Spinner.html#ad14608da9574e00b386f8ffbbc842b0a":[4,0,122,16],
-"classFl__Spinner.html#adbba4826fc8dfffd9bc594d855ace056":[4,0,122,6],
-"classFl__Spinner.html#ae00cbda8df08046a8e34bc86be41ace6":[4,0,122,27],
-"classFl__Spinner.html#aeb0fc8ca643e958084dde6c1e699d5b8":[4,0,122,2],
-"classFl__Spinner.html#aec26deb9377c69f430fe3153a08386de":[4,0,122,18],
-"classFl__Spinner.html#af29b3e59a3ef92aa7f13be5da993000d":[4,0,122,25],
-"classFl__Surface__Device.html":[4,0,123],
-"classFl__Surface__Device.html#a1162e0cf051b2c95dd88091ef3b833df":[4,0,123,2],
-"classFl__Surface__Device.html#a3993b12f96391f224a0d52a1fd15cfee":[4,0,123,4],
-"classFl__Surface__Device.html#a552dbc7bfdbf91ad4ad035de963e4aae":[4,0,123,5],
-"classFl__Surface__Device.html#a7ccd4356e0026af4f6cbfda08827a116":[4,0,123,1],
-"classFl__Surface__Device.html#ad65054e24f1b8a2a36a685495ea7776c":[4,0,123,3],
-"classFl__Surface__Device.html#ad9ee333db23389529698ef07efb6a2fe":[4,0,123,0],
-"classFl__Sys__Menu__Bar.html":[4,0,124],
-"classFl__Sys__Menu__Bar.html#a165b56c2f0384be5de9df905d845d37c":[4,0,124,7],
-"classFl__Sys__Menu__Bar.html#a1e3ff678e9804d60688acd8dc8ba4b87":[4,0,124,10],
-"classFl__Sys__Menu__Bar.html#a3815e6c6e10640a17f19edafd54dacc4":[4,0,124,8],
-"classFl__Sys__Menu__Bar.html#a3e0456479c69f59a0f6ba9085421a425":[4,0,124,13],
-"classFl__Sys__Menu__Bar.html#a57877fcd877c6b73796f99ea8dcbd792":[4,0,124,5],
-"classFl__Sys__Menu__Bar.html#a735ab2fbae8b9f306fad962e391d8a43":[4,0,124,4],
-"classFl__Sys__Menu__Bar.html#a745cf121ec001bc816acad5d465906e6":[4,0,124,14],
-"classFl__Sys__Menu__Bar.html#a8d32b547117221cb90f75817bc564dc3":[4,0,124,16],
-"classFl__Sys__Menu__Bar.html#aac8a5b85bd059dd77db4b38ff714427e":[4,0,124,18],
-"classFl__Sys__Menu__Bar.html#ac2b4c97648f88414bbf8e76926a3dad9":[4,0,124,9],
-"classFl__Sys__Menu__Bar.html#ac7bfcc1ad04ee91eb4f66fe9f9f5623f":[4,0,124,15],
-"classFl__Sys__Menu__Bar.html#ac87a5922c829cff8b20c1354003069ad":[4,0,124,19],
-"classFl__Sys__Menu__Bar.html#ad41479400953f29cbdafbddd1aed335a":[4,0,124,2],
-"classFl__Sys__Menu__Bar.html#ad9d9b1af865fb2acbac2dd687f23a36b":[4,0,124,3],
 "classFl__Sys__Menu__Bar.html#ade5c2840df6c3b4b564c09018ff6dc0d":[4,0,124,11],
 "classFl__Sys__Menu__Bar.html#af2b8b866c162d11abb2ce3422139ad0e":[4,0,124,6],
 "classFl__Sys__Menu__Bar.html#af31d1ed34661ad12c1cc8119f89af23f":[4,0,124,12],
@@ -249,5 +204,50 @@ var NAVTREEINDEX9 =
 "classFl__Text__Buffer.html#a1f908f95fe6359555d65702fdcfccf4d":[4,0,129,59],
 "classFl__Text__Buffer.html#a21f1df22ad9aaf8ade2975c8d95d1470":[4,0,129,78],
 "classFl__Text__Buffer.html#a2462945eb7e7c0a90775c9fa38aab187":[4,0,129,64],
-"classFl__Text__Buffer.html#a2a29f4f81620569bc03aa9fc7c652678":[4,0,129,65]
+"classFl__Text__Buffer.html#a2a29f4f81620569bc03aa9fc7c652678":[4,0,129,65],
+"classFl__Text__Buffer.html#a3194e63f030767326476d4e719d69a32":[4,0,129,83],
+"classFl__Text__Buffer.html#a32403bee1999664989e322aba9296138":[4,0,129,48],
+"classFl__Text__Buffer.html#a33f5490d3af576f0941d7e882a626253":[4,0,129,56],
+"classFl__Text__Buffer.html#a3b7ec7d6d20d6cbb8715f07213800409":[4,0,129,33],
+"classFl__Text__Buffer.html#a3d3058cd7d430b80467775500839d415":[4,0,129,75],
+"classFl__Text__Buffer.html#a415382fd677cc6c9572dabb866b6f27d":[4,0,129,93],
+"classFl__Text__Buffer.html#a4204e8113fa00b5a6f453290c3432b2b":[4,0,129,19],
+"classFl__Text__Buffer.html#a49a54f11bfb913a049734db9f8f79ef6":[4,0,129,0],
+"classFl__Text__Buffer.html#a4b561203f94b9754687cfc113b67c8c1":[4,0,129,26],
+"classFl__Text__Buffer.html#a4b5c16436b4d2878822ac7cf8b8f2403":[4,0,129,63],
+"classFl__Text__Buffer.html#a4bea04adc6132e9ee3cef0f46536a326":[4,0,129,89],
+"classFl__Text__Buffer.html#a4c29786fb9251e5422e8053ca7ca7510":[4,0,129,31],
+"classFl__Text__Buffer.html#a4c8cd9eab282964593c8fbdc11cb2781":[4,0,129,52],
+"classFl__Text__Buffer.html#a4ee6c0ffe96189a4308e062c6799dc79":[4,0,129,34],
+"classFl__Text__Buffer.html#a50e7d6784656a3d4c2f928e002c75e85":[4,0,129,87],
+"classFl__Text__Buffer.html#a5662f3d7b2cd153e6947a61a72950989":[4,0,129,17],
+"classFl__Text__Buffer.html#a57de562dffb0187a576d16eadc42ea75":[4,0,129,54],
+"classFl__Text__Buffer.html#a5c18c7e2dd09f0fad0892411c1ac273a":[4,0,129,8],
+"classFl__Text__Buffer.html#a5ead0cc57cc00bebf0390b977337a3b7":[4,0,129,12],
+"classFl__Text__Buffer.html#a5f7747ca80f516eefdc464c440b41dd0":[4,0,129,70],
+"classFl__Text__Buffer.html#a62e6f9378d36ceb1e980518b50110102":[4,0,129,7],
+"classFl__Text__Buffer.html#a643de0c99aef747d6c9a01ee0daa7679":[4,0,129,11],
+"classFl__Text__Buffer.html#a695b45d15b18ee80df6e44cc027fe3f7":[4,0,129,18],
+"classFl__Text__Buffer.html#a695bd49abdcda997913315736d63e090":[4,0,129,9],
+"classFl__Text__Buffer.html#a6a72d422478508c94baf5b6a7bc46740":[4,0,129,2],
+"classFl__Text__Buffer.html#a6a78d10cc4437d3029e347b9ded8cddb":[4,0,129,90],
+"classFl__Text__Buffer.html#a6b458132afd9a331b0254321b2e28b42":[4,0,129,22],
+"classFl__Text__Buffer.html#a6c1df9ed8edb351d000ab1a933907848":[4,0,129,5],
+"classFl__Text__Buffer.html#a6c7c4ff0f7f2b8379e53cdaf43e66650":[4,0,129,20],
+"classFl__Text__Buffer.html#a6cefc34659cfb802831cb4263b9caf35":[4,0,129,57],
+"classFl__Text__Buffer.html#a6f436f4fd49b7ddeab5a40d33022a606":[4,0,129,42],
+"classFl__Text__Buffer.html#a6fa246873065799765128f0378feced4":[4,0,129,69],
+"classFl__Text__Buffer.html#a6fb364932b62762721951651aea2eee7":[4,0,129,1],
+"classFl__Text__Buffer.html#a711cdd58b3142122f6f0649aa9e610d1":[4,0,129,43],
+"classFl__Text__Buffer.html#a76c9edaf534e9e09cccbbb5c29aa8e4d":[4,0,129,62],
+"classFl__Text__Buffer.html#a77204ed3084eaceee8bb67f35e0c9223":[4,0,129,88],
+"classFl__Text__Buffer.html#a7ce2676822142833a40b7408dc8fb3cc":[4,0,129,4],
+"classFl__Text__Buffer.html#a7e8280a4e2c163f378dc7bb02920943e":[4,0,129,36],
+"classFl__Text__Buffer.html#a80580268a8e7df40fe4644790bca6896":[4,0,129,10],
+"classFl__Text__Buffer.html#a92d82784c4f1236b6817a3e7b0152522":[4,0,129,23],
+"classFl__Text__Buffer.html#a955cb74bbdc68f299863e8459c49063c":[4,0,129,74],
+"classFl__Text__Buffer.html#a9a479cd4cef940ede8dcc86f16705d85":[4,0,129,45],
+"classFl__Text__Buffer.html#a9acb4950f29d6aa64a29e4ebe46e72f9":[4,0,129,96],
+"classFl__Text__Buffer.html#a9c8e388b568aa6ff98bb8703272ac01b":[4,0,129,95],
+"classFl__Text__Buffer.html#aa2c392f5efd9f75762ced592a75b9860":[4,0,129,98]
 };
